@@ -1,7 +1,6 @@
-
 // @EXPECTED: First type in variant must be default constructible to allow default construction of variant
 
-#include <variant.hpp>
+#include <mapbox/variant.hpp>
 
 // Checks that the first type in a variant must be default constructible to
 // make the variant default constructible.
